# opkhelper
# lib/buildsystem/autoconf.sh
# Build system plugin for GNU Autoconf.
#
# Copyright (C) 2012  Patrick "P. J." McDermott
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

[ "x${_OH_BUILDSYSTEM_AUTOCONF_SM+set}" = 'xset' ] && return 0
_OH_BUILDSYSTEM_AUTOCONF_SM=1

_oh_autoconf_can_configure()
{
	[ -x "${_OH_BUILDSYSTEM_SOURCE_DIR}/configure" ]
}

_oh_autoconf_configure()
{
	local arch_opts=
	local libdir=
	local rc=

	mkdir -p "${_OH_BUILDSYSTEM_BUILD_DIR}"
	cd "${_OH_BUILDSYSTEM_BUILD_DIR}"

	arch_opts="
		--build=$(oh_buildsystem_arch "${OPK_BUILD_ARCH}" 'autoconf')
		"
	if [ "${OPK_BUILD_ARCH}" != "${OPK_HOST_ARCH}" ]; then
		arch_opts="${arch_opts}
			--host=$(oh_buildsystem_arch \
				"${OPK_HOST_ARCH}" 'autoconf')"
	fi
	if [ "x${_OH_BUILDSYSTEM_TARGET_ARCH}" != 'x' ]; then
		arch_opts="${arch_opts}
			--target=$(oh_buildsystem_arch \
				"${_OH_BUILDSYSTEM_TARGET_ARCH}" 'autoconf')"
	fi

	if [ '@multiarch_libdir@' = 'yes' ]; then
		libdir='${prefix}/lib/'"${OPK_HOST_ARCH}"
	else
		libdir='${prefix}/lib/'
	fi

	"${_OH_BUILDSYSTEM_SOURCE_DIR}/configure" \
		--prefix='/usr' \
		--bindir='${prefix}/bin' \
		--sbindir='${prefix}/sbin' \
		--libexecdir="${libdir}" \
		--sysconfdir='/etc' \
		--localstatedir='/var' \
		--libdir="${libdir}" \
		--includedir='${prefix}/include' \
		--infodir='${prefix}/share/info' \
		--mandir='${prefix}/share/man' \
		${arch_opts} \
		--disable-maintainer-mode \
		--disable-dependency-tracking \
		"${@}"
	rc=${?}

	cd "${_OH_BUILDSYSTEM_WORK_AREA}"

	return ${rc}
}

_oh_autoconf_can_build()
{
	return 1
}

_oh_autoconf_can_clean()
{
	return 1
}

_oh_autoconf_can_test()
{
	return 1
}

_oh_autoconf_can_install()
{
	return 1
}

_oh_autoconf_testarch()
{
	# TODO: This should call config.sub, which may be in src or
	# src/conftools (or elsewhere?).
	return 0
}
